==> mx-repo-manager_23.11.tar.xz: BUILD/translations/mx-repo-manager_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="74"/>
        <source>MX Repo Manager</source>
        <translation>MX リボジトリ マネージャー</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="623"/>
        <source>Select the APT repository that you want to use:</source>
        <translation>使用したい APT リポジトリを選択して下さい:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>MX repos</source>
        <translation>MX リポジトリ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Select fastest MX repo for me</source>
        <translation>自分用の最速な MXリポジトリを選択</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>search</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Debian repos</source>
        <translation>Debian リポジトリ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="180"/>
        <source>Select fastest Debian repo for me</source>
        <translation>自分用に最速の Debianリポジトリを選択</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Individual sources</source>
        <translation>個々のソース</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Restore original APT sources</source>
        <translation>元の APTソースを復元</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>Display help </source>
        <translation>ヘルプ表示</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>About this application</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>About...</source>
        <translation>情報...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Quit application</source>
        <translation>アプリケーションの終了</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Apply</source>
        <translation>適用</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="165"/>
        <location filename="../mainwindow.cpp" line="472"/>
        <location filename="../mainwindow.cpp" line="766"/>
        <source>Success</source>
        <translation>成功</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="166"/>
        <location filename="../mainwindow.cpp" line="472"/>
        <location filename="../mainwindow.cpp" line="770"/>
        <source>Your new selection will take effect the next time sources are updated.</source>
        <translation>新しい選択は、ソースが更新された後で反映されます。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>Lists</source>
        <translation>一覧</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>Sources (checked sources are enabled)</source>
        <translation>ソース (チェックが入ったソースが有効)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="473"/>
        <location filename="../mainwindow.cpp" line="678"/>
        <location filename="../mainwindow.cpp" line="688"/>
        <location filename="../mainwindow.cpp" line="705"/>
        <location filename="../mainwindow.cpp" line="718"/>
        <location filename="../mainwindow.cpp" line="726"/>
        <location filename="../mainwindow.cpp" line="743"/>
        <location filename="../mainwindow.cpp" line="749"/>
        <location filename="../mainwindow.cpp" line="836"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="473"/>
        <source>Could not change the repo.</source>
        <translation>リボジトリを変更できませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="496"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>Please wait...</source>
        <translation>お待ち下さい...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="557"/>
        <source>About %1</source>
        <translation> %1 について</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="558"/>
        <source>Version: </source>
        <translation>バージョン: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="560"/>
        <source>Program for choosing the default APT repository</source>
        <translation>既定の APT リポジトリを選択するプログラム</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="562"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="563"/>
        <source>%1 License</source>
        <translation>%1 ライセンス</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="578"/>
        <source>%1 Help</source>
        <translation>%1 のヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="587"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="588"/>
        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
        <translation>MX テスト版リポジトリが選択されています。これを有効にしたままにしたり、そこから全てのパッケージをアップグレードしたりすることはお勧めできません。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="591"/>
        <source>A safer option is to install packages individually with MX Package Installer.</source>
        <translation>より安全なオプションは、MX パッケージ インストーラを使い、パッケージを個別にインストールすることです。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="625"/>
        <source>Select the APT repository and sources that you want to use:</source>
        <translation>利用したい APTリポジトリとソースを選択して下さい:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="678"/>
        <source>netselect-apt could not detect fastest repo.</source>
        <translation>netselect-apt は最速のレポを検出できませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="688"/>
        <location filename="../mainwindow.cpp" line="705"/>
        <source>Could not detect fastest repo.</source>
        <translation>最速のリポジトリを検出できませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="718"/>
        <source>Can&apos;t figure out if this app is running on antiX or MX</source>
        <translation>このアプリは antiX で動いているのか、MXで動いているのか分かりません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="727"/>
        <source>MX version not detected or out of range: </source>
        <translation>MX のバージョンが検出できないか、範囲外です。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="743"/>
        <source>Could not download original APT files.</source>
        <translation>元の APTファイルをダウンロードできませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="749"/>
        <source>Could not unzip downloaded file.</source>
        <translation>ダウンロードしたファイルを展開できません。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="760"/>
        <source>Enabling AHS</source>
        <translation>AHS を有効にしています</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="760"/>
        <source>Do you use AHS (Advanced Hardware Stack) repo?</source>
        <translation>AHS (Advanced Hardware Stack) を利用しますか？</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="767"/>
        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
        <translation>オリジナルの APTソースがリリース時の状態に復元されました。etc/apt/sources.list.d/ にある、ユーザーが追加したソースファイルには触れていません。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="837"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>ファイル %1 の書き込み中にエラー発生。ドライブに十分な空き領域があるか確認してください。</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>更新履歴</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <source>Cancel</source>
        <translation>取り消し</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="75"/>
        <source>&amp;Close</source>
        <translation>&amp;閉じる</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <location filename="../main.cpp" line="84"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="76"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>rootとしてログインしているようです。このプログラムを使用するには、一度ログアウトして通常のユーザーとしてログインしてください。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="85"/>
        <source>You must run this program with admin access.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mx-repo-manager_24.3.tar.xz: BUILD/translations/mx-repo-manager_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>MX Repo Manager</source>
        <translation>MX リボジトリマネージャ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="619"/>
        <source>Select the APT repository that you want to use:</source>
        <translation>使用したい APT リポジトリを選択して下さい:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>MX repos</source>
        <translation>MX リポジトリ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Select fastest MX repo for me</source>
        <translation>自分用の最速な MXリポジトリを選択</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>search</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Debian repos</source>
        <translation>Debian リポジトリ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="180"/>
        <source>Select fastest Debian repo for me</source>
        <translation>自分用に最速の Debianリポジトリを選択</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Individual sources</source>
        <translation>個々のソース</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Restore original APT sources</source>
        <translation>元の APTソースを復元</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>Display help </source>
        <translation>ヘルプ表示</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>About this application</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>About...</source>
        <translation>情報...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Quit application</source>
        <translation>アプリケーションの終了</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Apply</source>
        <translation>適用</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="166"/>
        <location filename="../mainwindow.cpp" line="471"/>
        <location filename="../mainwindow.cpp" line="761"/>
        <source>Success</source>
        <translation>成功</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="167"/>
        <location filename="../mainwindow.cpp" line="471"/>
        <location filename="../mainwindow.cpp" line="765"/>
        <source>Your new selection will take effect the next time sources are updated.</source>
        <translation>新しい選択は、ソースが更新された後で反映されます。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="297"/>
        <source>Lists</source>
        <translation>一覧</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="297"/>
        <source>Sources (checked sources are enabled)</source>
        <translation>ソース (チェックが入ったソースが有効)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <location filename="../mainwindow.cpp" line="674"/>
        <location filename="../mainwindow.cpp" line="684"/>
        <location filename="../mainwindow.cpp" line="701"/>
        <location filename="../mainwindow.cpp" line="714"/>
        <location filename="../mainwindow.cpp" line="721"/>
        <location filename="../mainwindow.cpp" line="738"/>
        <location filename="../mainwindow.cpp" line="744"/>
        <location filename="../mainwindow.cpp" line="831"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>Could not change the repo.</source>
        <translation>リボジトリを変更できませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="495"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>Please wait...</source>
        <translation>お待ち下さい...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="554"/>
        <source>About %1</source>
        <translation> %1 について</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="555"/>
        <source>Version: </source>
        <translation>バージョン: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="557"/>
        <source>Program for choosing the default APT repository</source>
        <translation>既定の APT リポジトリを選択するプログラム</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="559"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="560"/>
        <source>%1 License</source>
        <translation>%1 ライセンス</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="574"/>
        <source>%1 Help</source>
        <translation>%1 のヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="583"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="584"/>
        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
        <translation>MX テスト版リポジトリが選択されています。これを有効にしたままにしたり、そこから全てのパッケージをアップグレードしたりすることはお勧めできません。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="587"/>
        <source>A safer option is to install packages individually with MX Package Installer.</source>
        <translation>より安全なオプションは、MX パッケージ インストーラを使い、パッケージを個別にインストールすることです。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>Select the APT repository and sources that you want to use:</source>
        <translation>利用したい APTリポジトリとソースを選択して下さい:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>netselect-apt could not detect fastest repo.</source>
        <translation>netselect-apt は最速のレポを検出できませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="684"/>
        <location filename="../mainwindow.cpp" line="701"/>
        <source>Could not detect fastest repo.</source>
        <translation>最速のリポジトリを検出できませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="714"/>
        <source>Can&apos;t figure out if this app is running on antiX or MX</source>
        <translation>このアプリは antiX で動いているのか、MXで動いているのか分かりません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="722"/>
        <source>MX version not detected or out of range: </source>
        <translation>MX のバージョンが検出できないか、範囲外です。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="738"/>
        <source>Could not download original APT files.</source>
        <translation>元の APTファイルをダウンロードできませんでした。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="744"/>
        <source>Could not unzip downloaded file.</source>
        <translation>ダウンロードしたファイルを展開できません。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="755"/>
        <source>Enabling AHS</source>
        <translation>AHS を有効にしています</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="755"/>
        <source>Do you use AHS (Advanced Hardware Stack) repo?</source>
        <translation>AHS (Advanced Hardware Stack) を利用しますか？</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="762"/>
        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
        <translation>オリジナルの APTソースがリリース時の状態に復元されました。etc/apt/sources.list.d/ にある、ユーザが追加したソースファイルには触れていません。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="832"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>ファイル %1 の書き込み中にエラー発生。ドライブに十分な空き領域があるか確認してください。</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="49"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="50"/>
        <location filename="../about.cpp" line="60"/>
        <source>Changelog</source>
        <translation>更新履歴</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>Cancel</source>
        <translation>取り消し</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation>&amp;閉じる</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>rootとしてログインしているようです。このプログラムを使用するには、一度ログアウトして通常のユーザとしてログインしてください。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You must run this program with admin access.</source>
        <translation>このプログラムは管理者権限で実行してください。</translation>
    </message>
</context>
</TS>
